%-------------------------defaultParams.m--------------------------------
%author: XP     create date: 06/16/2005
%modified date:         by:
%---------------------------------------------------------------------
% purpose: Setup default PBPK parameters.
% units:
%   time   :  minutes; 
%   age    :  year(adult);  or days(infant);
%   weight :  kilogram(bodyWt);  or grams(organ);  or mg(protein)
%   volume :  litre;
%   conc   :  umol/litre;
%   
%---------------------------------------------------------------------    

function [organ, drug, enzyme, protein, const] = defaultParams()  

    % inialization
    [organ, drug, enzyme, protein, const] = inialization([], [], [], [], []);    
%    
%   %---------------------%
%    define a single simulated person
%   %---------------------%
%     
    const.person.age = 365*18/365;                     
    const.person.race = const.race.whiten;
    const.person.gender = const.gender.female;    
    const.person.bodyWt = []; %75;   % Kg
    const.person.bodyHt = []; %177; % cm
    const.person.PH = 7.4;  
    
    % read in perfusionRate 
    [organ, drug, enzyme, protein, const] = perfusionRate( ...
     organ, drug, enzyme, protein, const);    
 
    % read in basic information about binding protein      
    [organ, drug, enzyme, protein, const] = protBasics( ...
     organ, drug, enzyme, protein, const); 
 
    % read in PBPK parameeters data for methadone
    [organ, drug, enzyme, protein, const] = methadoneInfor(...
     organ, drug, enzyme, protein, const);
 
    % read in experimental data for methadone 
    [organ, drug, enzyme, protein, const] = methadoneExpData( ...
     organ, drug, enzyme, protein, const);
      
    % scaling to infant if necessary.    
    [organ,drug,enzyme,protein,const] = scale2Infant(...
     organ,drug,enzyme,protein,const);      
 
    % turn off all switches of optimizer     
    [organ,drug,enzyme,protein,const] = defaultOptimzer(false,...
     organ,drug,enzyme,protein,const); 

end  % end of deaultParams.m


%-------------------------inialization.m--------------------------------
%author: XP     create date: 06/16/2005
%modified date:         by:
%---------------------------------------------------------------------
function [organ, drug, enzyme, protein, const] = inialization( ...
          organ, drug, enzyme, protein, const)  
    
    % select organ.
    organ(1).number = 10;  % the acutal number of organs which is distributed by drug
    organ(1).name  = 'vein';
    organ(2).name  = 'artery';
    organ(3).name  = 'liver';
    organ(4).name  = 'intestine'; %(esophagus, stomach, small intestine; and large intestines),
    organ(5).name  = 'kidney';
    organ(6).name  = 'brain';
    organ(7).name  = 'lung';    
    organ(8).name  = 'muscle'; 
    organ(9).name  = 'spleen';      
    organ(10).name = 'heart';
    organ(11).name = 'skin';
    organ(12).name = 'adipose';  
    organ(13).name = 'thyroid';      
    organ(14).name = 'pancreas';   
    organ(15).name = 'redmarrow';      
    organ(16).name = 'yellowmarrow';  
    organ(17).name = 'bonetissue';
    
    % drug name.    
    drug(1).number = 2;
    drug(1).name = 'r_methadone';
    drug(2).name = 's_methadone';
    drug(3).name = 'r_EDDP';
    drug(4).name = 's_EDDP';
    drug(5).name = 'fentonyl';    %methadone inhibitors           
    drug(6).name = 'phenytoin';      %methadone inducer  common
    drug(7).name = 'rifampicin';       %methadone inducer  common 
    drug(8).name = 'nevirapine';     %methadone inducer     
    drug(9).name = 'carbamazepine';  %methadone inducer   x common
    drug(10).name = 'phenobarbital';  %methadone inducer   x
    drug(11).name = 'barbiturates';   %methadone inducer   x common           
    drug(12).name = 'ritonavir';       %methadone inhibitors
    drug(13).name = 'nifedipine';     %methadone inhibitors, Ki=10-22,100, mixed type, Vmax=2.13nmol, 8.9/10
    drug(14).name = 'quinidine';      %methadone inhibitors
    drug(15).name = 'diazepam';       %methadone inhibitors
    drug(16).name = 'fluvoxamine';    %methadone inhibitors    
    % barbiturate,diazepam,oral contraceptives,ritanovir

    % enzyme name.    
    enzyme(1).number = 3;    
    enzyme(1).name = 'CYP3A4';   
    enzyme(2).name = 'CYP3A5';
    enzyme(3).name = 'CYP3A7';     
    enzyme(4).name = 'CYP2D6';
    enzyme(5).name = 'CYP1A2';  %      'CYP2C';
    enzyme(6).name = 'CYP2B6';  %
    enzyme(7).name = 'CYP2E1';
    enzyme(8).name = 'CYP1A2';   
    enzyme(9).name = 'CYP2C';        

    % the name of binding protein involved.
    protein(1).number = 1;
    protein(1).name = 'ORM2';
    protein(2).name = 'albumin';                                                   
%    
%   %--------------------------%
%   % some constant parameters
%   %--------------------------%
%
    const.gender.male = 0;
    const.gender.female = 1;
    
    const.race.whiten = 1;
    const.race.blackn = 2;
    const.race.hispanic = 3;    
    const.race.african = 4;
    const.race.asian = 5;    
    
    const.density.adipose = 0.923;
    const.density.liver = 1.08; 
    const.density.other = 1.04;    
    const.density.blood = 1.06;       
%    
%   %--------------------------%
%   % inilizating all parameters
%   %--------------------------%
%    
     const.person.PH_SIGMA = 1.0;
     const.person.bodyWt_SIGMA = 1.0; 
     const.person.bodyHt_SIGMA = 1.0; 
     
    for iorgan = 1:length(organ)
    for isolute = 1:length(drug)
        for iprotein = 1:length(protein)
        for ienzyme = 1:length(enzyme)
            
            %drug(isolute).oralF_SIGMA = 0;
            drug(isolute).oralF_SIGMA = 1.0;  %biovailability   
            drug(isolute).Ka_SIGMA = 1;  %Absorption            
            
            % organ volume and blood flow rate
            organ(iorgan).V = 0;
            organ(iorgan).V_SIGMA = 1;            
            organ(iorgan).Q = 0;
            organ(iorgan).Q_SIGMA = 1;                        
            organ(iorgan).perfuseRateM = 0;
            organ(iorgan).perfuseRateF = 0; 
    
            % tissue:blood Partition Coeff 
            organ(iorgan).drug(isolute).parCoeff=1e-15;  %initial values.          
            organ(iorgan).drug(isolute).parCoeff_SIGMA = 1.0;
        
            % protein concentration
            organ(iorgan).protein(iprotein).conc = 0; 
            organ(iorgan).protein(iprotein).conc_SIGMA = 1;
            organ(iorgan).protein(iprotein).drug(isolute).K1 = 0.0;
            organ(iorgan).protein(iprotein).drug(isolute).K1_SIGMA = 1.0;        
    
            % permeability surface area
            organ(iorgan).drug(isolute).PS = 0; 
            organ(iorgan).drug(isolute).PS_SIGMA = 1;  
        
            % metabolism 
            organ(iorgan).drug(isolute).enzyme(ienzyme).Km1 = 0;        
            organ(iorgan).drug(isolute).enzyme(ienzyme).Vm1 = 0;  
            organ(iorgan).drug(isolute).enzyme(ienzyme).Vm1_SIGMA = 1;
            organ(iorgan).drug(isolute).enzyme(ienzyme).Km1_SIGMA = 1;  

            % renal clearnace
            organ(iorgan).drug(isolute).CL = 0.0;        
            organ(iorgan).drug(isolute).CL_SIGMA = 1;   
            
            % infant scaling factor
            enzyme(ienzyme).ISF = 1.0;         
            enzyme(ienzyme).ISF_SIGMA = 1.0;
            
            protein(iprotein).ISF = 1.0;         
            protein(iprotein).ISF_SIGMA = 1.0;            
        end
        end
    end 
    end       
end % end of inializationfunction


%-------------------------perfusionRate.m--------------------------------
%author: XP     create date: 06/16/2005
%modified date:         by:
%---------------------------------------------------------------------
function [organ, drug, enzyme, protein, const] = perfusionRate( ...
          organ, drug, enzyme, protein, const); 
 
    %assign index to each name  
    assignIndex();     
%      
%   Organ-Specific Perfusion Rates, (ml of blood/min/ml of organ     
%   From KAPKR (Williams and Legett, 1989), for both male and female 
    organ(kidney).perfuseRateM = 3.68;
    organ(kidney).perfuseRateF = 3.22;    
 
    organ(heart).perfuseRateM = 0.73;
    organ(heart).perfuseRateF = 0.96;
    
    organ(brain).perfuseRateM = 0.51;
    organ(brain).perfuseRateF = 0.52;
    
    organ(liver).perfuseRateM = 0.84;
    organ(liver).perfuseRateF = 1.00;
    
    organ(spleen).perfuseRateM = 1.00;
    organ(spleen).perfuseRateF = 1.04;
    
    organ(intestine).perfuseRateM = 0.75;
    organ(intestine).perfuseRateF = 0.78;
    
    organ(skin).perfuseRateM = 0.12;
    organ(skin).perfuseRateF = 0.15;
    
    organ(muscle).perfuseRateM = 0.03;
    organ(muscle).perfuseRateF = 0.03;

    organ(adipose).perfuseRateM = 0.02;
    organ(adipose).perfuseRateF = 0.03;      
    
    organ(thyroid).perfuseRateM = 5.0;
    organ(thyroid).perfuseRateF = 5.0;
    
    organ(pancreas).perfuseRateM = 0.60;
    organ(pancreas).perfuseRateF = 0.61;    
    
    organ(redmarrow).perfuseRateM = 0.30;
    organ(redmarrow).perfuseRateF = 0.30;
     
    organ(yellowmarrow).perfuseRateM = 0.03;
    organ(yellowmarrow).perfuseRateF = 0.03;   
end % end of perfusionRate function 


%-------------------------protBasics.m--------------------------------
%author: XP     create date: 06/16/2005
%modified date:         by:
%---------------------------------------------------------------------
function [organ, drug, enzyme, protein, const] = protBasics( ...
          organ, drug, enzyme, protein, const); 
 
    %assign index to each name  
    assignIndex();   
      
    % molecular weight.
    protein(ORM2).molWt = 23604;  
    protein(albumin).molWt = 66200;  %The ranges from 66000 to 69000, 

    % concentration
    organ(vein).protein(albumin).conc = 44/protein(albumin).molWt*1e+6; %4 gm/dl, 44 g/L albumin is 0.6646 mmol/L
    organ(vein).protein(ORM2).conc   = 6.6685; %0.17/protein(ORM2).molWt*1e+6; %33uM/L, the Plasma AAG 0.78mg/ml in intestines/liver, or 0.170mg/mL(Boulton), 1.150mg/ml(D.Foster,2000).    
end % end of protBasics



function [organ,drug,enzyme,protein,const ] = defaultOptimzer(option,organ,drug,enzyme,protein,const)

    % assign index to each name
    assignIndex();
%    
%   %-------------------------------------------%
%    default parameters for optimizer
%   %-------------------------------------------%
%   
if option == false
    for isolute = 1:drug(1).number
        const.person.PH_optimized = false; 
        drug(isolute).oralF_optimized = false;   % oral bioavailability. 
        drug(isolute).Ka_optimized = false;  %0.35/60;
        
        for i = 1:length(organ)
            % physiology
            organ(i).Q_optimized = false;
            organ(i).V_optimized = false;        
            organ(bonetissue).Q_optimized = false;            
            % physichemistry
            organ(i).drug(isolute).parCoeff_optimized = false;       
            organ(i).drug(isolute).PS_optimized = false;        
            % protein binding
            organ(i).protein(ORM2).conc_optimized = false;     
            organ(i).protein(ORM2).drug(isolute).K1_optimized = false;
            % metabolic rate
            for ienzyme = [CYP3A4 CYP3A5 CYP3A7]
            organ(i).drug(isolute).enzyme(ienzyme).Vm_optimized = false; 
            organ(i).drug(isolute).enzyme(ienzyme).Km_optimized = false;            
            end
        end
    end 
elseif option == true
    for isolute = 1:drug(1).number
        const.person.PH_optimized = true; 
        drug(isolute).oralF_optimized = true;   % oral bioavailability. 
        drug(isolute).Ka_optimized = true;  %0.35/60;
        
        for i = 1:length(organ)
            % physiology
            organ(i).Q_optimized = false;   
            organ(i).V_optimized = true;   
            organ(bonetissue).Q_optimized = false;
            % physichemistry
            organ(i).drug(isolute).parCoeff_optimized = true; 
            organ(i).drug(isolute).PS_optimized = false;        
            % protein binding
            organ(vein).protein(ORM2).conc_optimized = true;     
            organ(vein).protein(ORM2).drug(isolute).K1_optimized = false;
            % metabolic rate
            for ienzyme = [CYP3A4 ]% CYP3A5 CYP3A7]
            organ(liver).drug(isolute).enzyme(ienzyme).Vm_optimized = true; 
            organ(liver).drug(isolute).enzyme(ienzyme).Km_optimized = false;
            end
        end
    end 
end
    

end %end of defaultOptimzer



%-------------------------methadoneInfor.m--------------------------------
%author: XP     create date: 06/16/2005
%modified date:         by:
%---------------------------------------------------------------------
% purpose: input all information regarding methadone.
% units:
%   time   :  minutes; 
%   age    :  year(adult);  or days(infant);
%   weight :  kilogram(bodyWt);  or grams(organ);  or mg(protein)
%   volume :  litre;
%   conc   :  umol/litre;
%   
%---------------------------------------------------------------------    

function [organ, drug, enzyme, protein, const] = methadoneInfor(...
          organ, drug, enzyme, protein, const)
     
    % assign index to each name                       
    assignIndex();
%    
%   %-------------------------------------------%
%    basics about r-methadone
%   %-------------------------------------------%
%     
    % r-methadone
    %--------------    
    drug(r_methadone).molWt = 309.0;    %345.9;    %molecular weight for methadone.    
    drug(r_methadone).oralF = 0.850;     % oral bioavailability. 
    drug(r_methadone).Ka = 0.369/60;    % 0.369/60; absorption rate, min-1. 
  ratio = [ 14.1891    7.6182    6.7736    4.1047    1.8750    1.0000    0.8243];    
       
    parMuscle =  4.615; %4.327; % 5.1527; %3.898904; %6.635  %from r_methadone 6184,   3.3804(original) 
    organ(muscle).drug(r_methadone).parCoeff = parMuscle;
    organ(lung).drug(r_methadone).parCoeff   = ratio(1) * parMuscle; %from r_methadone 6184     
    organ(liver).drug(r_methadone).parCoeff  = ratio(2) * parMuscle;  %from r_methadone 6184
    organ(spleen).drug(r_methadone).parCoeff  = ratio(3) * parMuscle;  %from r_methadone 6184    
    organ(kidney).drug(r_methadone).parCoeff = ratio(4) * parMuscle;  %from r_methadone 6184
    organ(heart).drug(r_methadone).parCoeff = ratio(5) * parMuscle;  %from r_methadone 6184    
    organ(intestine).drug(r_methadone).parCoeff = 37.2/14.7 * parMuscle;  %from r_methadone 6184
    organ(brain).drug(r_methadone).parCoeff  = ratio(7) * parMuscle;  %from r_methadone 6184         
%     organ(adipose).drug(r_methadone).parCoeff  = 2.95/14.7 * parMuscle ;
%     organ(heart).drug(r_methadone).parCoeff  = 24/14.7 * parMuscle;   
%     organ(skin).drug(r_methadone).parCoeff   = 2.80/14.7 * parMuscle ;
%     organ(bonetissue).drug(r_methadone).parCoeff   = 1.20/14.7 * parMuscle;

    %PS(i) is the product of permeability surface area. 
    %------------------------------------------------%   
    organ(liver).drug(r_methadone).PS = 0;       % from Gabrielsson, 1985.   
    organ(intestine).drug(r_methadone).PS = 15.0; % ml/min, from Gabrielsson, 1985.      
    organ(brain).drug(r_methadone).PS = 0.25;    % ml/min, from Gabrielsson, 1985.   

    % Data for protein binding
    %-------------------------------------------%
   
    organ(vein).protein(ORM2).drug(r_methadone).K1 = 0.8532; %0.30 * 4.7e+4/1e+6;  1/(um/L)
    organ(vein).protein(albumin).drug(r_methadone).K1 = 320/1e+6;    
    
    % Data for metabolic rate
    %-------------------------------------------%
    %RAM = Vm1*c/(Km1+c) + Vm2*c/(Km2+c) 
 
    % 1) data from David Foster, 1998. not enzyme specific,but stereospecific,  using human liver microsomes
    Vm1 = 0.0094316; %0.018303; % ';
    organ(liver).drug(r_methadone).enzyme(CYP3A4).Vm1 =  Vm1*64/64; %0.001230339; %0.0101; 0.398386e-3; %0.7833e-3; %   ; %0.7833e-3; % 47nmol/mg protein/h-1 = 0.7833nmol/mg protein/min;  
    organ(liver).drug(r_methadone).enzyme(CYP3A4).Km1 =  198; 
    
    organ(liver).drug(r_methadone).enzyme(CYP3A5).Vm1 =  Vm1*5.2358/64; %0.001230339; %0.0101; 0.398386e-3; %0.7833e-3; %   ; %0.7833e-3; % 47nmol/mg protein/h-1 = 0.7833nmol/mg protein/min;  
    organ(liver).drug(r_methadone).enzyme(CYP3A5).Km1 =  198;  
    
    organ(liver).drug(r_methadone).enzyme(CYP3A7).Vm1 =  Vm1*0.3591/64; %0.001230339; %0.0101; 0.398386e-3; %0.7833e-3; %   ; %0.7833e-3; % 47nmol/mg protein/h-1 = 0.7833nmol/mg protein/min;  
    organ(liver).drug(r_methadone).enzyme(CYP3A7).Km1 =  198;     

    % total clearance
    %total_CL(r_methadone) = 161; % ml/min, from Boulton,2001, 158ml/min from Kristensen,1995. 
    %toEDDP_CL(r_methadone) = 21.9; %ml/min
    
    % both enzyme specific and stereospecific        
    % 1). data from Jun-Sheng Wang, 2003. enzyme specific and stereospecific
    % CLint of R-methadone for CYP3A4 is 20ml/min/kg
    % CLint of S-methadone for CYP3A4 is 4.8ml/min/kg 
    
    % CLint of R-methadone for CYP2D6 is 0.6ml/min/kg
    % CLint of S-methadone for CYP2D6 is 1.0ml/min/kg 
    
    
    % Data for renal clearance rate
    %-------------------------------------------%
    organ(kidney).drug(r_methadone).CL = 23.0e-3;       %23.0ml/min, from Boulton, 2001
    %organ(kidney).drug(r_methadone).CL = 27.4e-3;       %27.4ml/min, from D.Foster, 2000.    
    
%    
%   %-------------------------------------------%
%    basics about S-methadone
%   %-------------------------------------------%
%     
   % s-methadone    
    drug(s_methadone).molWt = 309.0;    %345.9;    %molecular weight for methadone.         
    drug(s_methadone).oralF = 0.850;     % oral bioavailability. 
    drug(s_methadone).Ka = 0.35/60;     %absorption rate, min-1.  
    

    % tissue:blood Partition Coeff of s-methadone.  
    %------------------------------%    
    % s_methadone
 
    parMuscle = 5.4023; %6.1934;% 6.0756; %5.59(original);
    ratio  = [8.3778    3.5698    3.9538    3.2374    2.0091    1.0000    0.4098];  
    organ(muscle).drug(s_methadone).parCoeff = parMuscle;    
    organ(lung).drug(s_methadone).parCoeff   = ratio(1) * parMuscle; %from r_methadone 6184     
    organ(liver).drug(s_methadone).parCoeff  = ratio(2) * parMuscle;  %from r_methadone 6184
    organ(spleen).drug(s_methadone).parCoeff  = ratio(3) * parMuscle;  %from r_methadone 6184    
    organ(kidney).drug(s_methadone).parCoeff = ratio(4) * parMuscle;  %from r_methadone 6184
    organ(heart).drug(s_methadone).parCoeff = ratio(5) * parMuscle;  %from r_methadone 6184       
    organ(intestine).drug(s_methadone).parCoeff = 37.2/14.7 * parMuscle;
    organ(brain).drug(s_methadone).parCoeff  = ratio(7) * parMuscle;  

%     organ(adipose).drug(s_methadone).parCoeff  = 2.95/14.7 * parMuscle ;
%     organ(heart).drug(s_methadone).parCoeff  = 24/14.7 * parMuscle;   
%     organ(skin).drug(s_methadone).parCoeff   = 2.80/14.7 * parMuscle ;
%     organ(bonetissue).drug(s_methadone).parCoeff   = 1.20/14.7 * parMuscle;

 
    %PS(i) is the product of permeability surface area. 
    %------------------------------------------------%   
    % s_methadone
    organ(liver).drug(s_methadone).PS = 0; 
    organ(intestine).drug(s_methadone).PS = 0;    

    % Data for protein binding
    %-------------------------------------------% 
    % K1, K2: binding constant for the protein( 1/(um/L));   
    organ(vein).protein(ORM2).drug(s_methadone).K1 = 1.2432; % ?    
    %organ(vein).protein(ORM2).drug(s_methadone).K2 = 8.40 * 620/1e+6;     % ?   
    
    % Data for metabolic rate
    %-------------------------------------------%
    %RAM = Vm1*c/(Km1+c) + Vm2*c/(Km2+c) 
 
    % 1) data from David Foster, 1998. not enzyme specific,but stereospecific,  using human liver microsomes 
    Vm1 =  0.027651; %0.055191;
    organ(liver).drug(s_methadone).enzyme(CYP3A4).Vm1 =  Vm1*64/64;  % 0.0041402; %0.6833e-3; % 41nmol/mg protein/h-1 = 0.6833nmol/mg protein/min;      
    organ(liver).drug(s_methadone).enzyme(CYP3A4).Km1 =  182; % 41nmol/mg protein/h-1 = 0.6833nmol/mg protein/min;  
            
    organ(liver).drug(s_methadone).enzyme(CYP3A5).Vm1 =  Vm1*7.5/64; %0.001230339; %0.0101; 0.398386e-3; %0.7833e-3; %   ; %0.7833e-3; % 47nmol/mg protein/h-1 = 0.7833nmol/mg protein/min;  
    organ(liver).drug(s_methadone).enzyme(CYP3A5).Km1 =  182;  
    
    organ(liver).drug(s_methadone).enzyme(CYP3A7).Vm1 =  Vm1*10/64; %0.001230339; %0.0101; 0.398386e-3; %0.7833e-3; %   ; %0.7833e-3; % 47nmol/mg protein/h-1 = 0.7833nmol/mg protein/min;  
    organ(liver).drug(s_methadone).enzyme(CYP3A7).Km1 =  182;     
    % Data for clearance rate
    %-------------------------------------------%
    organ(kidney).drug(s_methadone).CL = 13.2e-3;   % 13.2ml/min, from Boulton, 2001; 15.1ml/min; 27.4ml/min, from D.Foster, 2000. 
    %organ(kidney).drug(s_methadone).CL = 15.1e-3;         
end % end of methadoneInfor
    
    % References:
    % http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&dopt=Citation&list_uids=15371986 
    % http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&dopt=Citation&list_uids=11504799            
 
    

function [organ, drug, enzyme, protein, const] = methadoneExpData( ...
          organ, drug, enzyme, protein, const)
      
    % assign index to each name  
    drug(1).number = 2;     
    assignIndex();
    
%    
%   %----------------------------------------%
%    Reading experimental data for methadone
%   %----------------------------------------%
%
     
    % from Boulton, 2001, Figure 1. left panel. 
    %    (ng/ml vs hours), Plasma concentration  (ng/ml), with dose
    %    0.2mg/kg single oral dose of racemate.     
       drug(r_methadone).nphase = 1;     
       drug(r_methadone).Ka = 0.01855; %0.51/60;        %0.369/60;   0.00400787     
       drug(r_methadone).iphase(1).tSpan = [0 96*60]; 
       drug(r_methadone).iphase(1).inputType = [3];     % orally   
       drug(r_methadone).iphase(1).infuseT   = 0.5;  % infuse time, min.              
       drug(r_methadone).iphase(1).dose = [0.5*0.2];  % 0.2mg/kg  % %%%%%%%%%%%%%%%%%

       drug(r_methadone).iphase(1).range = [1 14];    
           drug(r_methadone).expData = [ ... 
     0.322	      8.54
     0.667	      19.1
      2		      27.3
      4		      34.4
      6.	      27.6
      8		      22.2
      10	      21.6
      12	      20.5
      16	      17.4
      24.	      18.8
      36	      15.7
      48	      11.4
      72.	      9.96
      96.	      6.83];
       drug(r_methadone).expData = [drug(r_methadone).expData(:,1).*60 ... 
                                    drug(r_methadone).expData(:,2)./drug(r_methadone).molWt];  
    
% from Boulton, 2001, Figure 1. left panel. 
%    (ng/ml vs hours), Plasma concentration  (ng/ml), with dose
%    0.2mg/kg single oral dose of racemate.     
       drug(s_methadone).nphase = 1;     
       drug(s_methadone).Ka = 0.018958; %0.51/60;        %0.369/60;   0.00400787     
       drug(s_methadone).iphase(1).tSpan = [0 72*60]; 
       drug(s_methadone).iphase(1).inputType = [3];     % orally   
       drug(s_methadone).iphase(1).infuseT   = 0.5;  % infuse time, min.              
       drug(s_methadone).iphase(1).dose = [0.5*0.2];  % 0.2mg/kg 

       drug(s_methadone).iphase(1).range = [1 12];    
           drug(s_methadone).expData = [ ... 
     0.294	      9.94
     0.576	      18.2
      3		      39.5
      4		      23.3
      6.	      19.9
      10	      15.9
      12.	        15
      16.	      11.3
      24.	      9.52
      36.	      8.31
      48	       5.4
      72	       2.7];
       drug(s_methadone).expData = [drug(s_methadone).expData(:,1).*60 ... 
                                    drug(s_methadone).expData(:,2)./drug(s_methadone).molWt];  

end  % end of methadoneExpData
      
    
 

function [organ,drug,enzyme,protein,const] = scale2Infant( ...
          organ,drug,enzyme,protein,const)

% Parameters unit
%       age:        unit: year
%       bodyWt:     unit: kg
%       gender:     'male'(0) or 'female'(1) 
%       bodyht:     cm, height. 
%       bodySA:     m^2, Body Serface Area(BSA).
%       volume:     ml, millilitre

     age = const.person.age;
     gender = const.person.gender;
     race = const.person.race;
     bodyWt = const.person.bodyWt;
     bodyHt = const.person.bodyHt;
     
    % assign index to each name                       
    assignIndex();
       
    %assume age if necessary         
    if length(age) == 0 | age == 0   age = 25;   end    
    %assume gender if necessary         
    if length(gender) == 0 | gender == 0   gender = const.gender.male;   end     
    %assume race if necessary         
    if length(race) == 0 | race == 0   race = const.race.whiten;   end     
    %compute body weight if necessary         
    if length(bodyWt) == 0 | bodyWt == 0   [const] = bodyWt_fun(const);   end    
    %compute body weight if necessary         
    if length(bodyHt) == 0 | bodyHt == 0   [const] = bodyHt_fun(const);   end  
    
    bodyWt = const.person.bodyWt;
    bodyHt = const.person.bodyHt;
      
%    
%   %-------------------------------------------------------%
%    begin to scale the Organ Volume based on personal data.
%   %-------------------------------------------------------%
%     
    selectedOrgans = 1:length(organ); %1:organ(1).number; 
    for iorgan = selectedOrgans
        %select which organ to scale 
        switch iorgan                             
           case liver  %compute liver volume    
               organ(liver).V = liverV_fun(age,gender,race,bodyWt,bodyHt,const);                     

           case vein %compute blood volume           
               bldV = bloodV_fun(age,gender,race,bodyWt,bodyHt,const);
               organ(vein).V = bldV*0.615;
               
           case artery  %compute blood volume           
               bldV = bloodV_fun(age,gender,race,bodyWt,bodyHt,const);
               organ(artery).V = bldV*0.385;               

           case brain   %compute brain volume        
               organ(brain).V = brainV_fun(age,gender,race,bodyWt,bodyHt,const);

           case heart  %compute heart volume 
               organ(heart).V = heartV_fun(age,gender,race,bodyWt,bodyHt,const);

           case intestine   %compute intestine volume 
               organ(intestine).V = intestineV_fun(age,gender,race,bodyWt,bodyHt,const);

           case kidney   %compute kidney volume 
               organ(kidney).V = kidneyV_fun(age,gender,race,bodyWt,bodyHt,const);

           case adipose   %compute lipid volume 
               organ(adipose).V = adiposeV_fun(age,gender,race,bodyWt,bodyHt,const);

           case lung   %compute lung volume 
               organ(lung).V = lungV_fun(age,gender,race,bodyWt,bodyHt,const);

           case muscle   %compute muscle volume 
               organ(muscle).V = muscleV_fun(age,gender,race,bodyWt,bodyHt,const);

           case spleen  %compute spleen volume 
               organ(spleen).V = spleenV_fun(age,gender,race,bodyWt,bodyHt,const);

           case skin  %compute skin volume 
               organ(skin).V = skinV_fun(age,gender,race,bodyWt,bodyHt,const);

           case pancreas  %compute pancreas volume           
               organ(pancreas).V = pancreasV_fun(age,gender,race,bodyWt,bodyHt,const);
               
           case thyroid  %compute thyroid volume           
               organ(thyroid).V = thyroidV_fun(age,gender,race,bodyWt,bodyHt,const); 
               
           case bonetissue  %compute bone volume 
               [organ(bonetissue).V organ(redmarrow).V organ(yellowmarrow).V]...
                    = boneV_fun(age,gender,race,bodyWt,bodyHt,const);
     
           case redmarrow  %compute redmarrow volume           
%                %organ(redmarrow).V = redmarrowV_fun(age,gender,race,bodyWt,bodyHt,const);
%                
           case yellowmarrow  %compute yellowmarrow volume           
%                organ(yellowmarrow).V = yellowmarrowV_fun(age,gender,race,bodyWt,bodyHt,const);               

           otherwise
               disp('entered oragan name is invalid');           
        end %end switch
    end  % end of loop for each organ  
       
%    
%   %----------------%
%    blood flow rate
%   %----------------%
%     
    % calculate the blood flow rate by anthropometry method. not used.
    cardiacOut = cardiacOut_fun(age,gender,race,bodyWt,bodyHt,const);

    % there is no blood flow in the bone tissue
    selectedOrgans = setdiff(1:length(organ),[lung,vein,artery,bonetissue]);
    sum0 = 0;   
    for i = selectedOrgans   % use perfusion rate method
        if gender == const.gender.male
            organ(i).Q = organ(i).V * organ(i).perfuseRateM;
        elseif gender == const.gender.female  
            organ(i).Q = organ(i).V * organ(i).perfuseRateF;
        end   
        sum0 = sum0 + organ(i).Q;
    end
    organ(lung).Q = sum0;        
    organ(vein).Q   = sum0;      
    organ(artery).Q =  sum0;   
    organ(bonetissue).Q = 0;  % dummy
%    
%   %------------------------------%
%    hepatic infant scaling factor 
%   %------------------------------%
%
    
    %compute hepatic infant scaling factor 
    [enzyme] = hepaticISF_fun(age,gender,race,bodyWt,bodyHt, ...
             organ, drug, enzyme, protein, const);	
         
    %compute glomerular filtration infant scalling factor 
    const.GFR_ISF = GFR_ISF_fun(age,bodyWt);
%    
%   %-----------------------%
%    protein concentration
%   %-----------------------%
%    
    %compute concentration of albumin 
    [protein] = prot_albumin_fun(age,gender,race,bodyWt,bodyHt,protein);
    
    %compute concentration of AAG!!!
    [protein] = prot_ORM2_fun(age,gender,race,bodyWt,bodyHt,protein);
    
    return
 
end  % end of scale2infant function.
  
    
%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  volume of brain in ml.
%------------------------------------------------------------
 function [const] = bodyHt_fun(const) 
 
 age = const.person.age;
 gender = const.person.gender;
 race = const.person.race;
 
    boyHeight = [...
         0   50.5000
    0.0157   51.5000
    0.0470   52.9000
    0.0705   54.2000
    0.0858   55.2000
    0.1175   56.4000
    0.1492   57.7000
    0.1725   58.6000
    0.2117   59.7000
    0.2508   60.9000
    0.2817   61.7000
    0.3058   62.4000
    0.3450   63.4000
    0.3842   64.4000
    0.3917   64.6000
    0.4075   64.9000
    0.4467   65.9000
    0.5017   67.1000
    0.5717   68.4000
    0.6342   69.6000
    0.6817   70.4000
    0.7283   71.3000
    0.7675   71.9000
    0.8300   72.9000
    0.8917   73.9000
    0.9583   74.9000
    1.0167   75.8000
    1.0667   76.4000
    1.1083   76.9000
    1.1500   77.6000
    1.2167   78.4000
    1.2667   79.3000
    1.3083   79.8000
    1.3667   80.4000
    1.4167   80.9000
    1.4667   81.4000
    1.5250   82.3000
    1.5917   83.0000
    1.6417   83.6000
    1.7083   84.3000
    1.7667   85.0000
    1.8167   85.5000
    1.8667   86.0000
    1.9167   86.6000
    1.9833   87.1000
    2.0500   87.2000
    2.2300   88.9000
    2.4700   90.9000
    2.6100   92.1000
    2.7900   93.6000
    2.9300   94.6000
    3.1700   96.3000
    3.3500   97.6000
    3.6300   99.6000
    3.8200  101.0000
    3.9600  102.0000
    4.1900  104.0000
    4.3800  105.0000
    4.6100  107.0000
    4.8900  108.0000
    5.1200  110.0000
    5.4000  111.0000
    5.5400  112.0000
    5.8200  114.0000
    5.9600  115.0000
    6.2400  117.0000
    6.4300  118.0000
    6.7100  120.0000
    6.9000  121.0000
    7.2200  123.0000
    7.4600  125.0000
    7.7800  127.0000
    7.8800  127.0000
    8.1100  129.0000
    8.3900  130.0000
    8.7200  132.0000
    8.9500  133.0000
    9.0900  134.0000
    9.1800  135.0000
    9.5100  136.0000
    9.9300  138.0000
   10.1000  139.0000
   10.5000  141.0000
   10.7000  142.0000
   11.1000  144.0000
   11.3000  145.0000
   11.7000  147.0000
   12.0000  149.0000
   12.3000  151.0000
   12.5000  153.0000
   12.8000  155.0000
   13.0000  156.0000
   13.2000  158.0000
   13.5000  160.0000
   13.7000  162.0000
   13.9000  163.0000
   14.2000  165.0000
   14.4000  166.0000
   14.6000  168.0000
   15.0000  170.0000
   15.3000  171.0000
   15.6000  172.0000
   15.9000  173.0000
   16.3000  174.0000
   16.6000  175.0000
   17.0000  175.0000
   17.3000  176.0000
   17.6000  176.0000
   18.0000  176.0000
   18.2000  176.0000
   18.6000  177.0000
   18.8000  177.0000
   18.9000  177.0000
   19.0000  177.0000
   19.2000  177.0000
   19.6000  177.0000
   19.8000  177.0000
   19.9000  177.0000
   20.0000  177.0000];


 girlHeight = [...      
    0.0078   50.0000
    0.0157   50.7000
    0.0235   51.2000
    0.0627   52.7000
    0.0858   53.7000
    0.1100   54.7000
    0.1175   55.0000
    0.1408   55.9000
    0.1883   57.4000
    0.2350   58.9000
    0.2900   60.4000
    0.3292   61.4000
    0.3917   62.9000
    0.4542   64.4000
    0.5017   65.4000
    0.5483   66.2000
    0.6033   67.4000
    0.6267   67.7000
    0.6733   68.6000
    0.7208   69.4000
    0.7442   69.7000
    0.7600   70.1000
    0.7992   70.7000
    0.8417   71.4000
    0.8917   72.2000
    0.9500   73.1000
    0.9833   73.6000
    1.0000   73.9000
    1.0583   74.8000
    1.1083   75.4000
    1.1583   75.9000
    1.2250   76.8000
    1.2750   77.6000
    1.3333   78.4000
    1.3833   79.1000
    1.4250   79.6000
    1.4417   79.8000
    1.5000   80.4000
    1.5083   80.6000
    1.5667   81.3000
    1.6000   81.6000
    1.6500   82.1000
    1.7000   82.8000
    1.7500   83.3000
    1.7583   83.4000
    1.7917   83.8000
    1.8417   84.3000
    1.8917   84.8000
    1.9333   85.3000
    2.0000   85.8000
    2.0583   86.3000
    2.1167   87.0000
    2.1583   87.6000
    2.2083   88.1000
    2.2583   88.6000
    2.3083   89.1000
    2.3417   89.5000
    2.4000   90.0000
    2.4250   90.3000
    2.4667   90.6000
    2.5083   91.0000
    2.5583   91.5000
    2.6000   91.8000
    2.6417   92.1000
    2.6750   92.5000
    2.7417   93.0000
    2.8000   93.3000
    2.8583   93.5000
    2.9250   94.1000
    2.9500   94.5000
    2.9667   94.7000
    2.9917   94.8000
    3.1700   95.1000
    3.3100   96.1000
    3.5400   97.8000
    3.7700   99.3000
    4.0500  101.0000
    4.2400  103.0000
    4.4200  104.0000
    4.5600  105.0000
    4.7500  106.0000
    4.9800  108.0000
    5.2200  109.0000
    5.4500  111.0000
    5.6800  112.0000
    5.8700  114.0000
    6.0100  115.0000
    6.2000  116.0000
    6.3400  117.0000
    6.4800  118.0000
    6.6600  119.0000
    6.9400  121.0000
    7.1800  123.0000
    7.4100  124.0000
    7.5000  125.0000
    7.8300  127.0000
    8.1100  128.0000
    8.4400  130.0000
    8.8100  132.0000
    9.2300  134.0000
    9.3200  134.0000
    9.4600  135.0000
    9.6000  136.0000
    9.9300  138.0000
   10.3000  139.0000
   10.5000  141.0000
   10.8000  143.0000
   11.0000  144.0000
   11.2000  145.0000
   11.3000  146.0000
   11.5000  147.0000
   11.7000  149.0000
   11.8000  150.0000
   12.1000  152.0000
   12.3000  153.0000
   12.5000  155.0000
   12.8000  156.0000
   12.9000  157.0000
   13.3000  159.0000
   13.7000  160.0000
   14.0000  160.0000
   14.5000  161.0000
   14.8000  162.0000
   15.2000  162.0000
   15.6000  162.0000
   16.0000  163.0000
   16.5000  163.0000
   16.8000  163.0000
   17.0000  163.0000
   17.3000  163.0000
   17.6000  163.0000
   18.0000  163.0000
   18.4000  163.0000
   18.6000  163.0000
   18.8000  163.0000
   19.0000  163.0000
   19.2000  163.0000
   19.5000  163.0000
   19.8000  163.0000
   19.9000  163.0000
   20.0000  163.0000   ];

    if age <= 20
        if gender == const.gender.male
            const.person.bodyHt = spline(boyHeight(:,1), boyHeight(:,2),age); 
        elseif gender == const.gender.female
            const.person.bodyHt = spline(girlHeight(:,1), girlHeight(:,2),age); 
        end
    elseif age > 20
        if gender == const.gender.male
            const.person.bodyHt = 177.0000;  % cm
        elseif gender == const.gender.female
            const.person.bodyHt = 163.0;  % cm
        end            
    end
    
    return
 end   % end of function  
 
% 
%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  body weight (kg).
%------------------------------------------------------------
 function [const] = bodyWt_fun(const)

 age = const.person.age;
 gender = const.person.gender;
 race = const.person.race;
 
 
 
 boyWeight = [...
         0    3.6000
    0.0158    3.7700
    0.0233    3.9000
    0.0550    4.1700
    0.0792    4.4000
    0.1000    4.6700
    0.1250    4.9000
    0.1417    5.0700
    0.1583    5.2300
    0.1833    5.4300
    0.2083    5.7000
    0.2250    5.9000
    0.2500    6.1000
    0.2833    6.3300
    0.3167    6.6000
    0.3417    6.7700
    0.3667    6.9300
    0.3833    7.1000
    0.4083    7.2700
    0.4500    7.5300
    0.4750    7.7000
    0.5000    7.9000
    0.5333    8.1300
    0.5750    8.3700
    0.6167    8.6000
    0.6500    8.7700
    0.6833    8.9700
    0.6917    9.0000
    0.7250    9.1700
    0.7667    9.3300
    0.8250    9.6000
    0.8333    9.7300
    0.9167    9.8700
    0.9267   10.1000
    1.0000   10.3000
    1.0833   10.6000
    1.1667   10.9000
    1.2500   11.1000
    1.3333   11.3000
    1.4167   11.5000
    1.5000   11.7000
    1.5833   11.9000
    1.6667   12.0000
    1.7500   12.1000
    1.8333   12.3000
    1.9167   12.5000
    2.0000   12.7000
    2.0833   12.8000
    2.1667   12.9000
    2.2500   13.1000
    2.3333   13.2000
    2.4167   13.3000
    2.5000   13.5000
    2.5833   13.6000
    2.6667   13.7000
    2.7500   13.9000
    2.8333   14.0000
    2.9167   14.2000
    3.0000   14.3000    
    3.2600   14.4000
    3.6300   14.5000
    3.9100   15.0000
    4.2800   15.8000
    4.6000   16.5000
    4.9300   17.3000
    5.2600   18.0000
    5.6300   18.8000
    6.0000   19.5000
    6.3700   20.6000
    6.7400   21.6000
    7.0700   22.3000
    7.3500   23.1000
    7.6300   23.8000
    8.0000   24.8000
    8.1900   25.3000
    8.5600   26.3000
    8.9300   27.3000
    9.2100   28.3000
    9.4900   29.3000
    9.8100   30.6000
   10.1000   31.8000
   10.4000   32.8000
   10.7000   33.8000
   11.0000   35.4000
   11.3000   36.9000
   11.7000   38.4000
   12.0000   40.1000
   12.1000   40.6000
   12.2000   41.1000
   12.6000   42.9000
   12.9000   44.6000
   13.3000   46.4000
   13.6000   48.1000
   13.9000   49.9000
   14.2000   51.7000
   14.3000   52.4000
   14.5000   53.4000
   14.8000   54.7000
   15.2000   56.7000
   15.3000   57.4000
   15.7000   58.9000
   16.0000   60.7000
   16.4000   62.2000
   16.7000   63.2000
   17.1000   64.4000
   17.4000   65.5000
   17.7000   66.2000
   18.0000   67.0000
   18.5000   68.0000
   18.9000   68.7000
   19.1000   69.0000
   19.4000   69.5000
   19.8000   70.0000
   20.0000   70.4000 
   21.000    71.5000
   22.000    72.5000
   23.0000   73.500  
   24.0000   74.3000 
   25.0000   75.000    ];
  

 girlWeight = [...
    0.0079    3.5000
    0.0233    3.7000
    0.0550    3.9300
    0.0833    4.2000
    0.1083    4.4000
    0.1333    4.6300
    0.1583    4.8300
    0.1833    5.0300
    0.2167    5.2700
    0.2333    5.4300
    0.2667    5.7000
    0.2917    5.8700
    0.3167    6.0300
    0.3417    6.2000
    0.3583    6.3000
    0.3833    6.5000
    0.4167    6.7000
    0.4333    6.8000
    0.4500    6.9000
    0.4917    7.1300
    0.5250    7.3700
    0.5667    7.6000
    0.6000    7.7700
    0.6250    7.9000
    0.6750    8.1300
    0.7000    8.2700
    0.7500    8.5000
    0.8000    8.7000
    0.8333    8.9000
    0.9167    9.0700
    1.0000    9.5300
    1.0833    9.7000
    1.1667   10.1000
    1.2500   10.3000
    1.3333   10.5000
    1.4167   10.7000
    1.5000   11.0000
    1.5833   11.2000
    1.6667   11.4000
    1.7500   11.5000
    1.8333   11.7000
    1.9167   11.9000
    2.0000   12.0000
    2.0833   12.2000
    2.1667   12.4000
    2.2500   12.5000
    2.3333   12.6000
    2.4167   12.8000
    2.5000   12.9000
    2.5833   13.1000
    2.6667   13.2000
    2.7500   13.4000
    2.8333   13.5000
    2.9167   13.7000
    3.0000   13.8000
    3.5400   14.2000
    3.6800   14.5000
    4.1000   15.3000
    4.4300   16.0000
    4.6600   16.5000
    5.0800   17.6000
    5.4100   18.3000
    5.6400   18.8000
    6.0600   19.9000
    6.3800   20.6000
    6.7600   21.7000
    7.1300   22.7000
    7.3600   23.5000
    7.7400   24.5000
    7.9700   25.3000
    8.2000   26.0000
    8.4400   26.8000
    8.8100   28.1000
    9.2300   29.9000
    9.5100   30.9000
    9.8800   32.4000
   10.1000   33.5000
   10.3000   34.2000
   10.6000   35.5000
   10.9000   36.8000
   11.2000   38.3000
   11.7000   40.1000
   11.9000   41.4000
   12.2000   42.7000
   12.6000   44.5000
   13.1000   46.3000
   13.4000   47.8000
   13.8000   49.4000
   14.2000   50.4000
   14.6000   51.7000
   15.0000   52.7000
   15.4000   53.5000
   15.9000   54.2000
   16.3000   55.0000
   16.7000   55.5000
   17.1000   56.0000
   17.5000   56.3000
   17.8000   56.5000
   18.1000   57.1000
   18.6000   57.6000
   18.7000   57.8000
   18.9000   58.1000
   19.2000   58.3000
   19.5000   58.6000
   19.8000   58.8000
   19.9000   58.8000
   20.0000   58.8000   ];

    if age <= 25 & gender == const.gender.male
            const.person.bodyWt = spline(boyWeight(:,1), boyWeight(:,2),age); 
    elseif age <= 20 & gender == const.gender.female 
            const.person.bodyWt = spline(girlWeight(:,1), girlWeight(:,2),age); 
    elseif age > 25 &  gender == const.gender.male
            const.person.bodyWt = 75.0000 ;  % kg
%            p1 =  5.782e-005; %  (-5.991e-006, 0.0001216)
%            p2 =    -0.01996; %  (-0.03011, -0.009804)
%            p3 =       1.522; %  (1.018, 2.026)
%            p4 =       50.95; %  (43.29, 58.62)              
%            const.person.bodyWt = p1*age^3 + p2*age^2 + p3*age + p4;
     elseif age > 20 & gender == const.gender.female
%            p1 =    -0.01247; %  (-0.01366, -0.01128)
%            p2 =       1.262; %  (1.137, 1.387)
%            p3 =       43.27; %  (40.3, 46.24)  
%            const.person.bodyWt = p1*age^2 + p2*age + p3;
           const.person.bodyWt = 58.8000;
    end
    
    return
 end   % end of function  
 
%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  body surface area in m^2 
%------------------------------------------------------------
 function [BSA] = BSA_fun(age,gender,race,bodyWt,bodyHt,const)

    % select models
    Gehan1970 = 0; 
    Haycock1978 = 0;
    DuBois = 0;
    Mosteller = 1;
     
    % models available     
    if Gehan1970  %  and George (1970) is recommended by the U.S. EPA 
        BSA = 0.0235*bodyHt^0.42246*bodyWt^0.51456;  %  %(R2 = not given)
    elseif Haycock1978
        BSA = bodyWt^0.5378*bodyHt^0.3964*0.024265; % (R2 = .998)
    elseif DuBois
        BSA  = 0.20247*(bodyHt/100)^0.725*bodyWt^0.425; %m^2
    elseif Mosteller 
        BSA = sqrt((bodyHt * bodyWt )/3600 );   %m^2
    end
    
    return
 end  % end of BSA_fun. 
 
%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,bodyWt(Kg),bodyHt(cm);
% Output:  blood volume in ml.
%------------------------------------------------------------
 function [bldV] = bloodV_fun(age,gender,race,bodyWt,bodyHt,const)
    % with small modification
   
    % vary by age
    if  age > 14  % adults
        if gender == const.gender.male
            bldV = (13.1*bodyHt + 18.05*bodyWt - 480)/0.5723; %R2=0.69;  % Blood volume (ml)
            % Plasma volume (ml)=  (1 - hct  0.91)*bldV; 
        elseif gender == const.gender.female   %   
            bldV = (35.5*bodyHt + 2.27*bodyWt - 3382)/0.6178;   %Blood volume (ml)
            % Plasma volume (ml)=  (1 - hct  0.91)*bldV; 
        end
    elseif  age > 2 & age <= 14  % 2 < age <=14
        if gender == const.gender.male
            logBV = 0.6459*log10(bodyWt) + 0.002743*(bodyHt) + 2.1324; %(R2 = .96);
        elseif gender == const.gender.female 
            if age > 2 & age <= 7  % in fact, age=2-6
                logBV = 0.6459*log10(bodyWt) + 0.002743*(bodyHt) + 2.1324; %(R2 = .96); 
            elseif age > 7 & age <= 14
                logBV = 0.6412*log10(bodyWt) + 0.001270*(bodyHt)+ 2.3169; %(R2 = .94);
            end
        end
        bldV = 10^(logBV);
    elseif  age > 0 & age <= 2   % in fact, age=0-1, both sex
        logBV = 0.7891*log10(bodyWt) + 0.004132*bodyHt + 1.8117; % (R2 = .95)     
        bldV = 10^(logBV);    
    end
      
    return    
    % notes
    %The hematocrit (Ht or HCT) and packed cell volume (PCV) are measures of
    %the proportion of blood volume that is occupied by red blood cells. It is
    %normally between 0.35 and 0.52, and slightly higher on average in males.
 end  % end of blood volume function


%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,bodyWt(Kg),bodyHt(cm);
% Output:  Adipose Tissue volume in ml.
%------------------------------------------------------------

 function [adiposeV] = adiposeV_fun(age,gender,race,bodyWt,bodyHt,const)
    %sex: const.gender.female  & male
   
    BMI = bodyWt/(bodyHt/100)^2;    % body mass index=BW (kg)/[BH (m)]^2.    
    if age >= 0
        Kvist1988 = 0;    Gray1990 =1;  Deurenberg199 = 0;
        if Kvist1988 %Over the Age of 25-56  Kvist et al. (1988)   (selected)
            if gender == const.gender.male
                adiposeV = (1.36*bodyWt/bodyHt - 42)*1000; %ml (R2 = .93)
            elseif gender == const.gender.female  
                adiposeV = (1.61*bodyWt/bodyHt - 38.3)*1000; %ml (R2 = .96)
            end
        elseif Gray1990   %  Grayand Fujioka (1990)  adults
            if gender == const.gender.male
                pct = 0.99*BMI - 1.32; %   (R2 = .68)
            elseif gender == const.gender.female 
                pct = 0.94*BMI + 10.77; % (R2 = .74)
            end
            adiposeV =  pct/100*bodyWt/const.density.adipose*1000;  
        elseif Deurenberg199    %ages 783
            if gender == const.gender.male                 
                %pct = 1.20*BMI + 0.23*age - 16.2; % (R2 = .79)  old one
                pct = 0.99*BMI - 1.32; %   (R2 = .68)
                adiposeV =  pct/100*bodyWt/const.density.adipose*1000; % 
            elseif gender == const.gender.female  
                pct = 1.20*BMI + 0.23*age - 5.4; % (R2 = .79)   
                adiposeV =  pct/100*bodyWt/const.density.adipose*1000; %                 
            end               
        end
    elseif age > 100 & age < 700  % age 3-18 years, not good when age<5.
        Ellis1997 = 1;
         if Ellis1997
            if gender == const.gender.male 
                if race == const.race.whiten 
                    BMC = 23.6*bodyWt+75.5*age-416.5;
                    LTM = 0.439*bodyWt+1.52*age-2.76;
                    %adiposeWt = 0.534*bodyWt - 1.59*age +3.03; %  (kg)                    
                    adiposeWt = bodyWt*1000 - BMC - LTM*1000;
                elseif race == const.blackn
                    BMC = 21.3*bodyWt + 106.3*age - 525.3;
                    LTM = 0.363*bodyHt + 0.388*bodyWt - 34.2;
                    adiposeWt = bodyWt*1000 - BMC - LTM*1000;
                    % or adiposeWt = 0.594*bodyWt - 0.381*bodyHt + 36.0;
                elseif race == const.hispanic
                    BMC = 16.9*bodyWt + 102.3*age - 437.2;
                    LTM = 0.424*bodyWt + 1.56*age - 2.98;
                    adiposeWt = bodyWt*1000 - BMC - LTM*1000;
                    % or adiposeWt = 0.591*bodyWt - 1.82*age + 3.36;
                end
            elseif gender == const.gender.female 
                adiposeWt = 0.642*bodyWt - 0.12*bodyHt - 0.606*age +8.98; % (R2 = .86)  kg
                adiposeWt = adiposeWt*1000;
            end
            adiposeV =  adiposeWt/const.density.adipose;  
         end
    elseif age <= 0 % (<3 Years) infants under the age of 1 year are taken\
        Koo2000 = 1;  % not good, too high
        if Koo2000
            adiposeWt = 908.4+0.706*(bodyWt*1000)-53*bodyHt + 358.5*gender-3.057*(age*365);  % g
            adiposeV =  adiposeWt/const.density.adipose;  
        end        
    end  % end of age
    
    return
 end   % end of function
 
%------------------------------------------------------------
% Poorly Perfused Tissues
% Muscle        Smooth muscle
% Skeletal muscle (minus intramuscular fat) 
% Epidermis
% Heart (cardiac muscle) 
% Dermis
%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  adipose tissue free skeletal muscle (ATFSM)in ml.
%------------------------------------------------------------
function [ATFSM] = muscleV_fun(age,gender,race,bodyWt,bodyHt,const)

    % calculate adipose volume
    adiposeV = adiposeV_fun(age,gender,race,bodyWt,bodyHt,const); %ml
    adiposeWt = adiposeV*const.density.adipose;   % g
    FFM = bodyWt*1000 - adiposeWt; % fat free mass.   g 
    if age >= 18    % Adults (Age 18 and Above)
        Clarys1984 = 1;
        if Clarys1984    
           if gender == const.gender.male 
                ATFSM = FFM * 54/100/const.density.other; % (kg/L); %   ATFSM volume (mL)
           elseif gender == const.gender.female  
                ATFSM = FFM * 48.9/100/const.density.other; % (kg/L)  % ATFSM volume (mL)
           end
        elseif Lee2000
            asian = 1.2; african = 1.4; whiten=0; hispanics = 0; 
            if gender == const.gender.male 
                ATFSM= [0.244*bodyWt + 7.8*bodyHt-0.098*age+3.3+race]/const.density.other;   %ATFSM volume (L) 
            elseif gender == const.gender.female  
                ATFSM = [0.244*bodyWt + 7.8*bodyHt-0.098*age-3.3+race]/const.density.other;  %ATFSM volume (L) 
            end
            ATFSM = ATFSM*1000;                
        end
    elseif age < 18    % age <=3, in fact, linearly.
       if gender == const.gender.female 
           pct = (48.9 - 30)/18 * age + 30;
       elseif gender == const.gender.male
           pct = (54 - 30)/18 * age + 30;
       end
       ATFSM = pct/100 * FFM / const.density.other;  % ml.
    end
    
    return
end % end of muscle 

%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  heart volume in ml.
%------------------------------------------------------------
function [heartV] = heartV_fun(age,gender,race,bodyWt,bodyHt,const)

    %   Heart (cardiac muscle) 
    if age < 180
        Ogiu1997 = 1;        
        if Ogiu1997  % ages 0 to 19  
            if gender == const.gender.male 
                heartWt = 22.81*(bodyHt/100)*bodyWt^0.5 - 4.15; % (R2 = .98) (g)
            elseif gender == const.gender.female  %Females:
                heartWt = 19.99*(bodyHt/100)*bodyWt^0.5 - 1.53; % (R2 = .96)
            end
        elseif Siebert1986  % (ages 011 years).
            %Males and const.gender.female s:
            heartWt = 4.289*bodyHt+0.494*bodyWt; %(R2 = .92)
        end
    elseif age >= 180
        Seo2000 = 1;         
    	if Seo2000  %    ages 176.
            if gender == const.gender.male %Males:
                heartWt = 155.18*(bodyHt^0.725*bodyWt^0.425*71.84/100^2)^1.29; % (R2 = .81)
            elseif gender == const.gender.female  %Females:
                heartWt = 124.13*(bodyHt^0.7763*bodyWt^0.4081*71.84/100^2)^1.242; % (R2 = .83)
            end
        end
    end
    heartV = heartWt/const.density.other;    %density of 1.04 g/cm3. 
    
    return
end  % end of heart volume

%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  skin volume in ml.
%------------------------------------------------------------
 function [skinV] = skinV_fun(age,gender,race,bodyWt,bodyHt,const)
   %^ gender = const.gender.female;  
    
    BSA = BSA_fun(age,gender,race,bodyWt,bodyHt,const);
    if age <= 1
        skinV = BSA/1000*(618*1);
    elseif age <= 10 & age > 1
        skinV = BSA/1000*(618*0.75+618*0.09+618*0.10+1200*0.025+1500*0.035);
    elseif age <= 18 & age > 10   % ?????
        skinV = BSA/1000*((1834-663)/8*(age-10)+663);        
    elseif age > 18
        skinV = BSA/1000*(2055*0.75+1109*0.09+1109*0.10+1200*0.025+1500*0.035);
    end
    
    skinV = skinV*1000/const.density.other;
    return
 end  % end of skin volume
  
%------------------------------------------------------------
% Well-Perfused Tissues
%   Red marrow        Adrenals
%   Liver             Breasts
%   Spleen            Thyroid
%   Thymus            Pancreas
%   Brain             Lungs
%   Kidney and other urogenital organs     
%   Gastrointestinal organs
%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  liver volume in ml.
%------------------------------------------------------------
 function liverV = liverV_fun(age,gender,race,bodyWt,bodyHt,const)
 
    if age > 19
       Noda1997 = 1;  Heinemann1999 = 0;
       if Heinemann1999 
            BSA = BSA_fun(age,gender,race,bodyWt,bodyHt,const);
            liverV = (1.0728*BSA - 345.7) * 1000;  % ml
       elseif Noda1997 % ages range from 10 days to 22 years, using CT.
            liverV = 0.05012*bodyWt^0.78 *1000;  %ml
       end
    elseif age <= 19 
        Ogiu1997 = 1;
        if Ogiu1997  % ages 0 to 19 reported by  
            if gender == const.gender.male 
                liverWt = 576.9*(bodyHt/100) + 8.9*bodyWt-159.7;   %(R2 = .92)  g
            elseif gender == const.gender.female  
                liverWt = 674.3*(bodyHt/100) + 6.5*bodyWt-214.4; % (R2 = .94)  g
            end
        end
        liverV = liverWt/const.density.liver; %    1.08 g/ml (Heinemann et al., 1999).        
    end

    return
 end % end of liverV function

%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  volume of spleen in ml.
%------------------------------------------------------------
 function spleenV = spleenV_fun(age,gender,race,bodyWt,bodyHt,const)

    Watanabe1997 = 1;  Ogiu1997 = 0;   Schlesinger1993 =0;
    if age < 0
        if Ogiu1997  %ages 0 to 19 reported  
            if gender == const.gender.male 
                spleenWt = 8.74*(bodyHt/100)* bodyWt^0.5 +11.06; % (R2 = .74) g
            elseif gender == const.gender.female  
                spleenWt = 9.36*(bodyHt/100)*bodyWt^0.5 +7.98;  %(R2 = .79)
            end
            spleenV = spleenWt/const.density.other; 
        elseif Schlesinger1993  % ages 1 day to 18 years using CT.  
            spleenV = 0.7 + 4.6*bodyWt;  % (R = .72)
        end
    elseif  age >= 0
        if Watanabe1997  % using CT (age range from 9 days to 25 years). 
            spleenV = 6.516*bodyWt^0.797;    %(R = .81)
        end
    end
    
    return
 end  % end of function 


%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  volume of kidney in ml.
%------------------------------------------------------------
 function kidneyV = kidneyV_fun(age,gender,race,bodyWt,bodyHt,const) 
%     
    if age > 22
        Kasiske1986 = 1;  Gilja1995 = 0;
        if Gilja1995  %  ages 22 to 36.
            %(const.gender.male = 1, const.gender.female  = 2)
            kidneyV = (5.04*gender+2.53*age+1.31*bodyWt+1.36*bodyHt-255.7)*2; % (R2 = .75)
        elseif Kasiske1986    % (mean age 37).
            kidneyWt = 15.4 + 2.04*bodyWt + 51.8*(bodyHt/100)^2; %  (R2 = .64)  g
            kidneyV = kidneyWt/const.density.other;
        end
    elseif age <= 22
        Dinkel1985 = 0;  Ogiu1997=1;
        if Ogiu1997  % ages 319 reported by Ogiu et al. (1997) 
            if gender == const.gender.male  
                leftKidneyWt = 10.24*(bodyHt/100)*bodyWt^0.5 +7.85; %  (R2 = .92)  g
                rightKidneyWt = 9.88*(bodyHt/100)*bodyWt^0.5 +7.2; % (R2 = .92)
            elseif gender == const.gender.female   %Females:
                leftKidneyWt = 10.65*(bodyHt/100)*bodyWt^0.5 + 6.11;  %(R2 = .92)
                rightKidneyWt = 9.88*(bodyHt/100)*bodyWt^0.5 + 6.55; % (R2 = .92)
            end
            kidneyV = (rightKidneyWt + leftKidneyWt)/const.density.other;
        elseif Dinkel1985  % ages 3 days and 15 years.   used
            leftKidneyV = 4.214*bodyWt^0.823; % (R2 = .97)   ml
            rightKidneyV = 4.456*bodyWt^0.795; % (R2 = .97)  ml
            kidneyV = leftKidneyV + rightKidneyV;
        elseif Troell1988   %ages 8 months to 15 years  
            kidneyV = 4.0*bodyWt; % (R2 = not reported)
        end
    end  % end of age
    
    return
 end  % end of function
 
 
%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  volume of brain in ml.
%------------------------------------------------------------
 function brainV = brainV_fun(age,gender,race,bodyWt,bodyHt,const)
 
    if age < 180
        Dekaban1978 = 1; Ogiu1997 = 0;
        if Ogiu1997  %   ages 319:
            if gender == const.gender.male 
                brainWt = ((-90.7*bodyHt/100) + 178.1)*bodyWt;   %(R2 = .90) g
            elseif gender == const.gender.female 
                brainWt = (-97.5*(bodyHt/100) + 181.2)*bodyWt; % (R2 = .88)
            end
            brainWt = min(brainWt,1700);  % g, the maximum size of the brain is capped at 1.7 kg.
        elseif Dekaban1978  % age 1-80
            brainWt = 1.449 - 3.62/bodyWt;
            brainWt = brainWt * 1000;
        end
    elseif age >= 180
        % Based on Ho et al. (1980), adult brain volumes (density of the brain is assumed to be 1.04 kg/L).
        brainWt = 1322;  %g
        if race == const.race.whiten  
            if gender == const.gender.male 
                brainWt = 1392;   %g 1.338 L
            elseif gender == const.gender.female  
                brainWt = 1252; % g  1.204 L
            end
        elseif race == const.race.african 
            if gender == const.gender.male 
                brainWt = 1286; % g  1.237 L
            elseif gender == const.gender.female 
                brainWt = 1158; % g  1.113 L
            end
        end
    end  % end of age
    brainV = brainWt/const.density.other;  
    
    return
 end  % end of function


%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  volume of lung in ml.
%------------------------------------------------------------
 function lungV = lungV_fun(age,gender,race,bodyWt,bodyHt,const)
 
    if age <= 100  
        Ogiu1997 = 1;
        if Ogiu1997  %  0 to 19.
            if gender == const.gender.male     %Males:
                leftLungWt = 29.08*(bodyHt/100)*bodyWt^0.5 +11.06; % (R2 = .70) g
                rightLungWt = 35.47*(bodyHt/100)*bodyWt^0.5 +5.53; % (R2 = .75)
                lungWt = leftLungWt + rightLungWt;
            elseif gender == const.gender.female   %Females:
                leftLungWt = 31.46*(bodyHt/100)*bodyWt^0.5 +1.43;  %(R2 = .83)
                rightLungWt = 35.30*(bodyHt/100)*bodyWt^0.5 +1.53; %(R2 = .83)
                lungWt = leftLungWt + rightLungWt;                
            end
        end
    elseif age >= 180
        adiposeV = adiposeV_fun(age,gender,race,bodyWt,bodyHt,const); %ml
        adiposeWt = adiposeV*const.density.adipose;   % g
        FFM = bodyWt*1000 - adiposeWt; % fat free mass.   g         
        if gender == const.gender.male 
            lungWt = 0.021*FFM; % for male.
        elseif gender == const.gender.female 
            lungWt = 0.019*FFM; 
        end
    end
    lungV = lungWt/const.density.other;

    return    
 end   % end of function 

%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  volume of pancreas in ml.
%------------------------------------------------------------
  function pancreasV = pancreasV_fun(age,gender,race,bodyWt,bodyHt,const)
% Ogiu et al. (1997). children and young adults, aged 0 to 19.
      if age <= 250 & age > 0
        if gender == const.gender.male   %Males:
            pancreasWt = 7.46*(bodyHt/100)*bodyWt^0.5-0.79; %(R2 = .92) g
        elseif gender == const.gender.female 
            pancreasWt = 7.92*(bodyHt/100)*bodyWt^0.5-2.09; %(R2 = .88)
        end
        pancreasV = pancreasWt/const.density.other;
    elseif age > 250        
        adiposeV = adiposeV_fun(age,gender,race,bodyWt,bodyHt,const); %ml
        adiposeWt = adiposeV*const.density.adipose;   % g
        FFM = bodyWt*1000 - adiposeWt; % fat free mass.   g
        if gender == const.gender.male
            pancreasWt = 0.0017*FFM; % male
        elseif gender == const.gender.female 
            pancreasWt = 0.0020*FFM;  % const.gender.female 
        end       
        pancreasV = pancreasWt/const.density.other;         
    end
    
    return;
  %  pancreas 0.1(0.085) kg,         0.0017(0.0020)    
  end
  
%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  volume of thyroid in ml.
%------------------------------------------------------------
  function thyroidV = thyroidV_fun(age,gender,race,bodyWt,bodyHt,const)

  % Ogiu et al. (1997). children and young adults, aged 0 to 19.
    if age <= 190 & age > 0
        if gender == const.gender.female   %Males:
            thyroidWt = 1.17*(bodyHt/100)*bodyWt^0.5-0.29; % (R2 = .71) g
        elseif gender == const.gender.male %Females:
            thyroidWt = 1.46*(bodyHt/100)*bodyWt^0.5-0.33;% (R2 = .83)
        end
        thyroidV = thyroidWt/const.density.other; 
    elseif age > 190        
        adiposeV = adiposeV_fun(age,gender,race,bodyWt,bodyHt,const); %ml
        adiposeWt = adiposeV*const.density.adipose;   % g
        FFM = bodyWt*1000 - adiposeWt; % fat free mass.   g
        if gender == const.gender.male
            thyroidWt = 0.00034*FFM; % male
        elseif gender == const.gender.female 
            thyroidWt = 0.00043*FFM;  % const.gender.female 
        end       
        thyroidV = thyroidWt/const.density.other;         
    end
    
    return;
  %  thyroid  0.02 (0.018),          0.00034 (0.00043)
end

%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  volume of intestine in ml.
%------------------------------------------------------------
 function intestineV = intestineV_fun(age,gender,race,bodyWt,bodyHt,const)
    % GI organs 1.207 1.134, organs of the gastrointestinal     
    % (esophagus, stomach, small intestine; and large intestines),
    adiposeV = adiposeV_fun(age,gender,race,bodyWt,bodyHt,const); %ml
    adiposeWt = adiposeV*const.density.adipose;   % g
    FFM = bodyWt*1000 - adiposeWt; % fat free mass.   g
    if gender == const.gender.male
        intestineWt = 0.021*FFM; % male
    elseif gender == const.gender.female 
        intestineWt = 0.027*FFM;  % const.gender.female 
    end
    intestineV = intestineWt/const.density.other;
    
    return;
 end  % end of function 
 
%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  volume of bone in ml.
%------------------------------------------------------------
 function [bonetissueV, redmarrowV, yellowmarrowV] = boneV_fun( ...
          age,gender,race,bodyWt,bodyHt,const)   
      
%           age = 0.7933;
%           gender=1;
%           race=5; 
%           bodyWt=8.8523;
%           bodyHt=71.6222;
          
    % bone density
    %http://hypertextbook.com/facts/2002/AnnaYarusskaya.shtml
    redMarrowDensity = 1.03;
    yellowMarrowDensity = 0.98;
    boneTissueDensity = 1.75;   % rance from 1.65-1.85;kg/L.
    boneDensity = 1.9;    % overall skeletal density.
    
%   Weight fraction of TBBM, Table 8.   total body bone mineral (TBBM)
        if age <= 1  
            WFTBBM = 0.33;     
        elseif age <= 5 & age > 1
            WFTBBM = 0.38; 
        elseif age <= 10 & age > 5
            WFTBBM = 0.4; 
        elseif age <= 15 & age > 10
            WFTBBM = 0.4; 
        elseif age <= 21 & age > 15
            WFTBBM = 0.43; 
        elseif age <= 35 & age > 21
            if gender == const.gender.male
                WFTBBM = 0.48; 
            elseif gender == const.gender.female
                WFTBBM = 0.48;                 
            end            
        elseif age <= 40 & age > 35
            if gender == const.gender.male
                WFTBBM = 0.48; 
            elseif gender == const.gender.female
                WFTBBM = 0.48;                 
            end
        elseif age <= 45 & age > 40
            if gender == const.gender.male
                WFTBBM = 0.48; 
            elseif gender == const.gender.female
                WFTBBM = 0.47;                 
            end
        elseif age <= 50 & age > 45
            if gender == const.gender.male
                WFTBBM = 0.47; 
            elseif gender == const.gender.female
                WFTBBM = 0.45;                 
            end 
        elseif age <= 55 & age > 50
            if gender == const.gender.male
                WFTBBM = 0.47; 
            elseif gender == const.gender.female
                WFTBBM = 0.43;                 
            end 
        elseif age <= 60 & age > 55
            if gender == const.gender.male
                WFTBBM = 0.45; 
            elseif gender == const.gender.female
                WFTBBM = 0.42;                 
            end  
        elseif age > 60  
            if gender == const.gender.male
                WFTBBM = 0.45; 
            elseif gender == const.gender.female
                WFTBBM = 0.40;                 
            end 
        end
      
    % for weight fraction of bone tissue, red marrow and yellow marrow.
        if age <= 1
            WFB = 0.773;
            WFRM = 0.227;
            WFYM = 0.00001;   % very samll number
        elseif age <= 5 & age > 1
            WFB = 0.776;
            WFRM = 0.197;
            WFYM = 0.026;
        elseif age <= 10 & age > 5
            WFB = 0.716;
            WFRM = 0.193;
            WFYM = 0.091;
        elseif age <= 15 & age > 10
            WFB = 0.646;
            WFRM = 0.177;
            WFYM = 0.177;
        elseif age <= 18 & age > 15
            if gender == const.gender.male
                WFB = 0.613;
                WFRM = 0.163;
                WFYM = 0.224;
            elseif gender == const.gender.female
                WFB = 0.609;
                WFRM = 0.164;
                WFYM = 0.227;
            end                
        elseif age > 18  
            if gender == const.gender.male            
                WFB = 0.601;
                WFRM = 0.128;
                WFYM = 0.271;
            elseif gender == const.gender.female
                WFB = 0.597;
                WFRM = 0.134;
                WFYM = 0.269;
            end
        end
 
     % caluclate the TBBM.   
    adiposeV = adiposeV_fun(age,gender,race,bodyWt,bodyHt,const); %ml
    adiposeWt = adiposeV*const.density.adipose;   % g
    FFM = bodyWt*1000 - adiposeWt; % fat free mass.   g          
    if age > 180
        if gender == const.gender.male
            if age <= 50
                TBBM = 0.058*FFM;
            elseif age > 50 & age <= 60
                TBBM = 0.054*FFM;
            elseif age > 60
                TBBM = 0.046*FFM;
            end
        elseif gender == const.gender.female
            if age <= 50
                TBBM = 0.051*FFM;
            elseif age > 50 & age <= 60
                TBBM = 0.048*FFM;
            elseif age > 60
                TBBM = 0.047*FFM;
            end
        end
    elseif age >= 3 & age <= 180
        Proesmans1994 = 1; Ogle1995 = 0; Ellis1997=0;
        if Ogle1995
            if gender == const.gender.male
                TBBM = 60.9*FFM/1000 - 288.5;
            else gender == const.gender.female
                TBBM = 75.5*FFM/1000 - 516;
            end
        elseif Proesmans1994
            TBBM = 7.4*bodyHt + 28.9*bodyWt-789.6;
        elseif Ellis1997
            if gender == const.gender.male
                TBBM = 51.25*FFM/1000 - 258.8;
            else gender == const.gender.female
                TBBM = 66.25*FFM/1000 - 379.5;
            end  
        end            
    elseif age < 3
        % age ranging from 0-1 years
        TBBM = 77.24 + 24.94*bodyWt + 0.21*age*365 - 1.889*bodyHt;
    end
    
    boneMass = TBBM/WFTBBM;
    % output   
    bonetissueV = boneMass*WFB/boneTissueDensity;
    redmarrowV = boneMass*WFRM/redMarrowDensity;
    yellowmarrowV = boneMass*WFYM/yellowMarrowDensity;
    
 end   % end of bone function
        
 
function redmarrowV = redmarrowV_fun(age,gender,race,bodyWt,bodyHt,const);
end
          
function yellowmarrowV = yellowmarrowV_fun(age,gender,race,bodyWt,bodyHt,const); 
end 

%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  volume of cardiacOut in ml/min.
%------------------------------------------------------------
function cardiacOut = cardiacOut_fun(age,gender,race,bodyWt,bodyHt,const)
    %A.Resting Cardiac Output in PBPK models of average adults, 5.8 L/min
    %(Anderson et al., 1987; Clewell et al., 1999) 
    Katori1979 = 0;
    deSimone1997 = 1;
    
    BSA = BSA_fun(age,gender,race,bodyWt,bodyHt,const);
    if Katori1979  % Katori (1979)   (ages 414). T 
        if age < 14 
             cardiacOut = 21.008*(bodyHt/100)-22.508 * 1000; % (R2 = .38) (L/min)
        elseif age >= 14    % In adults  (ages 1478)
            cardiacOut = 31.847*BSA-45.704 * 1000; % (R2 = .26)
        end
    end

    if deSimone1997  %de Simone et al. (1997) 
        if age < 18   %Children: ages 1 day to 18 years)
            cardiacOut = 3294*BSA^0.53;  % (R2 = .30) (ml/min)
        elseif age >= 18  %Adults:ages 18 to 85
            cardiacOut = 2421*BSA^1.15;  % (R2 = .25)
        end
    end
    
    return;
end  % end of function 
 


%------------------------------------------------------------
% From Paul S. Price, 2003
% Input :  age(year),gender,race,bodyWt(Kg),bodyHt(cm);
% Output:  volume of thyroid in ml.
%------------------------------------------------------------
  function inhalationRate = inhalationRate_fun(age,gender,race,bodyWt,bodyHt,const)
    %B.Inhalation Rates

    %by Layton (1993) given in the U.S. EPA Exposure Factors Handbook (U.S. EPA, 1997a). 
    %Daily average inhalation rate (m3/day)
    %= BMR (MJ/day)  VQ  A  OU (m3O2/MJ)

    % where BMR is the basal metabolic rate (MJ/day),
    % VQ is the ventilation equivalent and has a value
    % of 27 (unit less), oxygen uptake/energy expended
    % (OU) is the oxygen uptake per megajoule of energy
    % expended and has a value of 0.05 (m3O2/MJ), and
    % A is the ratio of the food-energy intake to BMR.
    % Age-, gender-, and weight-specific values for A and
    % BMR are taken from the Exposure Factors Handbook,
    % Tables 512 and 5A-4 (U.S. EPA, 1997).
    inhalationRate = 0;
    return;
  end
 

 %-------------------hepaticISF_fun(age)---------------------------
 %equation: a*exp(bx)+c*exp(dx)
 %Modeling data from Morse et al.(1947)
 %Input :  age in year;
 %Output:  L/min/kg tissue   %ml/min
 %------------------------------------------------------------
 function [enzyme] = hepaticISF_fun(age,gender,race,bodyWt,bodyHt, ...
             organ, drug, enzyme, protein, const);	
 
    % assign index to each name                       
    assignIndex();

%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    % CYP3A4
%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    if age < 18
       % age = 0.5;
       p1 =  1.023e+004;%  (-9.307e+004, 1.135e+005)
       q1 =      -120.5;%  (-1176, 935.2)
       q2 =        2310;%  (-2.076e+004, 2.538e+004)    
       %f = (p1) / (age^2 + q1*age + q2);
       f=-8.3212+2.0401*age + 4.1962*log(age*365);        
       enzyme(CYP3A4).ISF = f/64; 
    else
       enzyme(CYP3A4).ISF = 1; 
    end
 
     
%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    %CYP3A5
%%%%%%%%%%%%%%%%%%%%%%%%%%%    

    if age < 18
        f = 3.2827+0.07205*age + 0.08206*log(age*165);
        enzyme(CYP3A5).ISF = f/5.2358; 
    else
        enzyme(CYP3A5).ISF = 1.0; 
    end

%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% CYP3A7  
%%%%%%%%%%%%%%%%%%%%%%%%%%%
  if age < 2.3
       %p1 =        16.4; %  (7.396, 25.4)
       %q1 =      0.1066; %  (0.03654, 0.1767)
       %f = (p1) / (age + q1);  
       f = 162.2407+5.1011*age-25.7863*log(age*365);
       enzyme(CYP3A7).ISF = f/0.3591; 
  else
       enzyme(CYP3A7).ISF = 0.0; 
  end

  return;
       
  
  
  
        
  
    age = age*365;
    
    use_model = 1;
    use_piecewise = 0;
    if use_piecewise 
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % for ontogeny scaling factor (OSF)
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % OSF is the elimination capacity of a specific enzyme in the infant
        % relative to the adult, a function of infant age and particular enzyme.
        % Assume: enzyme activity represent the relative abundance of functional
        % enzyme. 
        if age > 3000 % 30 weeks  %(fetus)
            OSF(CYP1A2) = 0;
            OSF(CYP2C)  = 0;
            OSF(CYP2D6) = 0; %unkown
            OSF(CYP2E1) = 0.032;    
            OSF(CYP3A4) = 0.034; 
            RHSF = 1.123;    
        elseif age <= 1 % day      & age > 1
            OSF(CYP1A2) = 0.012;
            OSF(CYP2C)  = 0;
            OSF(CYP2D6) = 0.041;  
            OSF(CYP2E1) = 0.21;    
            OSF(CYP3A4) = 0.091; 
            RHSF = 1.157;
        elseif age <= 7 & age > 1  % day       
            OSF(CYP1A2) = 0.019;
            OSF(CYP2C)  = 0.016;
            OSF(CYP2D6) = 0.085;  
            OSF(CYP2E1) = 0.31;    
            OSF(CYP3A4) = 0.13; 
            RHSF = 1.310;
        elseif age <= 28 & age > 8 % day       
            OSF(CYP1A2) = 0.033;
            OSF(CYP2C) = 0.041;
            OSF(CYP2D6) = 0.25;  
            OSF(CYP2E1) = 0.37;    
            OSF(CYP3A4) = 0.30; 
            RHSF = 1.394;
        elseif age <= 3*30 & age > 30 % day      
            OSF(CYP1A2) = 0.067;
            OSF(CYP2C) = 0.31;
            OSF(CYP2D6) = 0.0 ; %unkown
            OSF(CYP2E1) = 0.39;    
            OSF(CYP3A4) = 0.43; 
            RHSF = 1.218;    
        end   %end of age

        % ISF = RHSF * OSF;
        ISF([CYP1A2 CYP2C CYP2D6 CYP2E1 CYP3A4]) = ...
             OSF([CYP1A2 CYP2C CYP2D6 CYP2E1 CYP3A4]) .*RHSF;  
         for i = 1:length(ISF)
             enzyme(i).ISF = ISF(i);
         end
         
    end  % end of use_pieciewise

    if use_model 
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % for infant scaling factor (ISF)
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        if age < 180  % days
            % age in days;%
            % ISF0 is the scaled in vivo CYP(only) enzyme activity present at birth
            % ISFD is a fitted parameter
           
            ISF0(CYP1A2) = 0.0;
            ISF0(CYP2C)  = 0.0;
            ISF0(CYP2D6) = 0.0;
            ISF0(CYP2E1) = 0.0363;
            ISF0(CYP3A4) = 0.0381;

            ISFD(CYP1A2) = 0.20;
            ISFD(CYP2C)  = 0.419;
            ISFD(CYP2D6) = 2.76;
            ISFD(CYP2E1) = 0.46;
            ISFD(CYP3A4) = 0.446;

            k1(CYP1A2) = 0.0104;
            k1(CYP2C)  = 0.129;
            k1(CYP2D6) = 0.0065976;
            k1(CYP2E1) = 1.11;
            k1(CYP3A4) = 0.0980;
            for i = [CYP1A2 CYP2C CYP2D6 CYP2E1 CYP3A4]
              enzyme(i).ISF = ISF0(i) + ISFD(i)*(1-exp(-k1(i)*age));
            end     
        end  %end of age<180 days
    end %end of use_model
    
    if age > 180
        for i = [CYP1A2 CYP2C CYP2D6 CYP2E1 CYP3A4]
          enzyme(i).ISF = 1; 
        end
    end
end %end of hepatic_ISF.


 %-------------------GFR_ISF_fun(age)---------------------------
 %equation: a*exp(bx)+c*exp(dx)
 %Modeling data from Morse et al.(1947)  Renal clearance
 %Input :  age in year;
 %Output:  L/min/kg tissue   %ml/min
 %------------------------------------------------------------
 function GFR_ISF = GFR_ISF_fun(age,bodyWt)
    % where j is the index of different enzyme, CYP3A4, CYP2D6
    % GFR is glomerular filtration
 
        if 0  % from Alcorn, J. and P. J. McNamara (2002a).
            ISF0 = 0.957;
            ISFD = 1.837;
            k1   = 0.0017;
            ISF(GFR) = ISF0 + ISFD*(1-exp(-k1*age));
            GFR = ISF(GFR) * GFR;
        end
        if 1% from William L. Hayton1
            a = 2.6;  b = 0.662; c = 8.14; kmat = 0.0822; 
            GFR = a*bodyWt^b*exp(-kmat*age) + c*bodyWt^b*(1-exp(-kmat*age));  %ml/min
            GFR_ISF = GFR/99.8609;
        end
        %Glomerular Filtration (L/min/kg tissue)
 end
 

 %-------------------prot_albumin_fun(age)---------------------------
 % 1). plasma protein binding are lower in the infant than the adult.
 % 2). Albumin proteins concentration are 75%-80% of adult values. 81%
 % 3). AAG is initially half the adult value.   38.5%
 % C(albumin) = 36; % g/l; in umbilical cord blood.
 % C(albumin) = 45; % g/l; in adult
 %------------------------------------------------------------
 function [protein] = prot_albumin_fun(age,gender,race,bodyWt,bodyHt,protein);
    
 albumin = 2; 
    age =age*365;
   cPct = 0.005627*age + 76.7;  % from Patrick J. McNamara
   protein(albumin).ISF = min(cPct, 100)/100;
   
   %concAlbumin_out  = cPct/100*concAlbumin_in;  % convert from adult to infant.

 end
 
%-------------------prot_AAG_fun(age)---------------------------
% C(AAG)  = 0.2g/L;  % in cord
% C(AAG) =  0.38g/L; % in adult
%------------------------------------------------------------
function [protein]  = prot_ORM2_fun(age,gender,race,bodyWt,bodyHt,protein);
  
 ORM2 = 1;
age =age*365;

    cPct = 0.01137*age + 53.4;  % from Patrick J. McNamara
    protein(ORM2).ISF  = min(cPct, 100)/100;       %about age = 12, 100% 
    
    protein(ORM2).ISF = 55.446/100;
    
    %concORM2_out  = cPct/100*concORM2_in;  % convert from adult to infant.
 
end


 
 
  